@@ -169,7 +169,7 @@ bool RdpView::start()
             setStatus(Connected);
             break;
         case RdpSession::State::Closed:
-            setStatus(Disconnected);
+            startQuitting();
             break;
         default:
             break;
